# -*- coding: utf-8 -*-
"""
Tests of neo.io.neuroshareio
"""

# needed for python 3 compatibility
from __future__ import absolute_import, division

try:
    import unittest2 as unittest
except ImportError:
    import unittest

#from neo.io import NeuroshareIO

#~ class TestNeuroshareIO(unittest.TestCase):
    #~ pass


if __name__ == "__main__":
    unittest.main()
